@@ -4,12 +4,12 @@ from TextPreprocessing.utility import process_text
 class preprocess:
     
     def __init__(self):
-        self.__version__ = "1.5.0"
+        self.__version__ = "1.5.1"
         self.obj = process_text()
         self.start = 1
 
     def cleanup(self, text, end):
-        text = self.obj.clear_generic_entities(text)
+        text = self.obj.clear_generic_entity(text)
         text = str(text).lower().replace('\\', '').replace('_', ' ')
         text = self.obj.convert_abbreviations(text)
         text = self.obj.clear_email_id(text)
